@@ -33,6 +33,10 @@
 # v2014-07-04 Paco neue Email und neuer Link
 # v2014-07-21 Paco es werden nur Konstateneinträge berücksichtigt, deren
 #                  Statis ACTIVE=1 ist
+# v2014-08-01 Paco Logging kann jetzt in eine Datei geleitet werden
+#                  Parameter
+#                  - detailLogging
+#                  - logFile
 ######################################################################
 ####  Variables that should be adapted if necessary
 ####------------------------------------------------------------------
@@ -68,10 +72,17 @@ $connection = null;
 $mode = "";
 # output
 $tmpHTML = "";
-#
-$debugMeConstant = 0;
+# change next value to 1 if you want to activate logging
+$logConstant = $iniParams["detailLogging"];
+$logFile = $iniParams["logFile"];
+$configFile = 'conf/oplist.ini';
 ######################################################################
 
+
+date_default_timezone_set('Europe/Vienna');
+setlocale (LC_TIME, "de_DE");
+
+
 $header = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN">
     <html><head>
     <title>'.$projectName.'</title>
@@ -82,7 +93,7 @@ $header = '<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN">
     <body link="#0000FF" vlink="#0000FF">
     <div class="header"><img src="img/logo.jpg" width=114 height=48 border=0 alt="OPList">';
 
-$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v1.7.523 (2014-07-30)</small></div></body></html>';
+$footer = '</div><div class="footer"><small>&copy; 2011 by <a href="http://software.glawar.at/oplist/" target="_blank">OPList</a> v1.8.526 (2014-07-30)</small></div></body></html>';
 
 
 session_start();
@@ -93,15 +104,65 @@ session_start();
 #session_destroy();
 
 
-function debugMe($debugText){
-    global $debugMeConstant;
+#---------------------------------------------------------------------
+# (c) www.glawar.at: ergibt YYY-MM-DD HH:MM:SS
+#---------------------------------------------------------------------
+function getActualDateAndTime() {
+    return strftime("%Y-%m-%d %H:%M:%S");
+}
 
-    if ($debugMeConstant == 1) {
-        echo $debugText;
+
+#---------------------------------------------------------------------
+# (c) www.glawar.at: schreibt den uebergebenen Text in das LogFile
+#                    sofern $debugSQL im OPLIST.INI auf 1 gestellt wurde
+#---------------------------------------------------------------------
+function debugIntoFile($debugText){
+    global $debugSQL;
+    global $logFile;
+
+    if ($debugSQL == 1) {
+        #echo $debugText;
+        file_put_contents($logFile, "[".getActualDateAndTime()."] ".$debugText."\n", FILE_APPEND | LOCK_EX);
     }
 }
 
 
+#---------------------------------------------------------------------
+# (c) www.glawar.at: schreibt den uebergebenen Text in das LogFile
+#                    sofern $logConstant auf 1 gestellt wurde
+#---------------------------------------------------------------------
+function logIntoFile($logText){
+    global $logConstant;
+    global $logFile;
+
+    if ($logConstant == 1) {
+        file_put_contents($logFile, "[".getActualDateAndTime()."] ".$logText."\n", FILE_APPEND | LOCK_EX);
+    }
+}
+
+# Check new parameter and create them if necessary
+if (!isset($logConstant)) {
+    logIntoFile("Wir setzen detailLogging");
+    $logConstant = 0;
+    file_put_contents($configFile, "; ####------------------------------------------------------------------\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "; # 1: detailliertes Logging in Datei wird aktiviert\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "; # 0: detailliertes Logging ist deaktivert\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "detailLogging = 0;\n", FILE_APPEND | LOCK_EX);
+} else {
+    logIntoFile("logConstant hat einen Wert - naemlich <".$logConstant.">");
+}
+
+if (!isset($logFile)) {
+    logIntoFile("Wir setzen logFile");
+    $logFile = 'log/oplist.log';
+    file_put_contents($configFile, "; ####------------------------------------------------------------------\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "; # Name der Logdatei\n", FILE_APPEND | LOCK_EX);
+    file_put_contents($configFile, "logFile = log/oplist.log\n", FILE_APPEND | LOCK_EX);
+} else {
+    logIntoFile("configFile hat einen Wert - naemlich <".$configFile.">");
+}
+
+
 #---------------------------------------------------------------------
 # (c) www.glawar.at: liefert in Abhaengigkeit der obigen Parameter in
 #                    $connection eine gueltige Datenbankverbindung
@@ -264,9 +325,10 @@ function debugIntoDB ($debugText) {
     $content = substr($debugText, 0, $len);
 
     $sQuery = "INSERT INTO OPLIST_DEBUG (VALUE) VALUES ('".str_replace("'", "''", $content)."')";
-    if ($debugSQL == 1) {
-        echo "<p><b>Insert into Logging-Table:</b>".$sQuery."</p>";
-    }
+    debugIntoFile ("Insert into Logging-Table: <".$sQuery.">");
+    #if ($debugSQL == 1) {
+    #    echo "<p><b>Insert into Logging-Table:</b>".$sQuery."</p>";
+    #}
     $result = getRessource($sQuery);
     echo getError();
     freeRessource($result);
@@ -282,9 +344,10 @@ function getEmailOfId ($userId) {
     $retVal = null;
 
     $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE OPUID = ".$userId." AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL";
-    if ($debugSQL == 1) {
-        echo "<p><b>Email-Select:</b>".$sQuery."</p>";
-    }
+    debugIntoFile("Email-Select: <".$sQuery.">");
+    #if ($debugSQL == 1) {
+    #    echo "<p><b>Email-Select:</b>".$sQuery."</p>";
+    #}
     $result = getRessource($sQuery);
     echo getError();
     while ($val = getRow($result)) {
@@ -353,9 +416,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         $pass = sanitize($_POST['PASS'], $sanitizeUserPwd);
 
         $sQuery = "SELECT OPU.OPUID, OPU.OPGID, OPU.OPUEMAIL, OPU.OPULNAME, OPU.OPUFNAME, OPG.OPGTEXT FROM OPLIST_USERS OPU, OPLIST_GROUP OPG WHERE OPG.OPGID = OPU.OPGID AND OPU.OPUACTIVE = 1 AND UPPER(OPU.OPUUSERNAME) = UPPER('".$user."') AND OPU.OPUPASSWORD = '".transformPwd($pass)."'";
-        if ($debugSQL == 1) {
-            echo "<p><b>Login-Select:</b>".$sQuery."</p>";
-        }
+        debugIntoFile("Login-Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo "<p><b>Login-Select:</b>".$sQuery."</p>";
+        #}
         $result = getRessource ($sQuery);
         echo getError();
 
@@ -426,9 +490,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
     $header .= "<option value='-1'>Alle Stati</option>";
 
     $sQuery = "SELECT OPSID, OPSTEXT FROM OPLIST_STAT WHERE (ACTIVE=1) ORDER BY OPSID";
-    if ($debugSQL == 1) {
-        echo "<p><b>Status-Select:</b>".$sQuery."</p>";
-    }
+    debugIntoFile("Status-Select: <".$sQuery.">");
+    #if ($debugSQL == 1) {
+    #    echo "<p><b>Status-Select:</b>".$sQuery."</p>";
+    #}
     $result = getRessource($sQuery);
     echo getError();
     $statArr = array();
@@ -454,9 +519,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
     $header .= "</select>";
 
     $sQuery = "SELECT OPAID, OPATEXT FROM OPLIST_AREA WHERE (ACTIVE=1) ORDER BY OPATEXT";
-    if ($debugSQL == 1) {
-        echo "<p><b>Bereichs-Select:</b>".$sQuery."</p>";
-    }
+    debugIntoFile("Bereichs-Select: <".$sQuery.">");
+    #if ($debugSQL == 1) {
+    #    echo "<p><b>Bereichs-Select:</b>".$sQuery."</p>";
+    #}
     $result = getRessource($sQuery);
     echo getError();
     $typeArr = array();
@@ -485,9 +551,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
 
 
     $sQuery = "SELECT OPPID, OPPTEXT FROM OPLIST_PRODUCT WHERE (ACTIVE=1) ORDER BY OPPTEXT";
-    if ($debugSQL == 1) {
-        echo "<p><b>Produkte-Select:</b>".$sQuery."</p>";
-    }
+    debugIntoFile("Produkte-Select: <".$sQuery.">");
+    #if ($debugSQL == 1) {
+    #    echo "<p><b>Produkte-Select:</b>".$sQuery."</p>";
+    #}
     $result = getRessource($sQuery);
     echo getError();
     $productArr = array();
@@ -522,9 +589,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
     <div class='logoutMenuBar'><a class='menuitem' title='Benutzer abmelden' href='?mode=logout'><img src='img/lock.png' width=32 height=32 border=0 hspace=5 alt='Benutzer abmelden'></a></div></div>
     <div id='content' style=''>";
     $sQuery = "SELECT * FROM OPLIST_USERS ORDER BY UPPER(OPUUSERNAME)";
-    if ($debugSQL == 1) {
-        echo "<p><b>Benutzer-Select:</b>".$sQuery."</p>";
-    }
+    debugIntoFile("Benutzer-Select: <".$sQuery.">");
+    #if ($debugSQL == 1) {
+    #    echo "<p><b>Benutzer-Select:</b>".$sQuery."</p>";
+    #}
     $result = getRessource($sQuery);
     echo getError();
     $userArr = array();
@@ -572,9 +640,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             "OPGID = " . $_POST["OPGID"] .
             " WHERE OPUID = ".$_POST["OPUID"];
 
-        if ($debugSQL == 1) {
-            echo "<p><b>Update-User-Select:</b>".$sQuery."</p>";
-        }
+        debugIntoFile("Update-User-Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo "<p><b>Update-User-Select:</b>".$sQuery."</p>";
+        #}
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
@@ -591,9 +660,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             $tempPwdString.
             "OPUFNAME = '" . $_POST["OPUFNAME"] . "' " .
             "WHERE OPUID = ".$_POST["OPUID"];
-        if ($debugSQL == 1) {
-            echo "<p><b>Update-User-Select:</b>".$sQuery."</p>";
-        }
+        debugIntoFile("Update-User-Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo "<p><b>Update-User-Select:</b>".$sQuery."</p>";
+        #}
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
@@ -622,17 +692,19 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             $_POST["OPUEMAIL"] . "', '" .
             transformPwd($_POST["OPUPASSWORD"]) . "', " .
             $OPUACTIVE . ", ".$dateNow.")";
-        if ($debugSQL == 1) {
-            echo "<p><b>Neuer-Benutzer-Select:</b>".$sQuery."</p>";
-        }
+        debugIntoFile("Neuer-Benutzer-Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo "<p><b>Neuer-Benutzer-Select:</b>".$sQuery."</p>";
+        #}
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
     } else if (!empty($_POST['deleteuser'])) {
         $sQuery = "DELETE FROM OPLIST_USERS WHERE OPUID = ".$_POST["OPUID"];
-        if ($debugSQL == 1) {
-            echo "<p><b>Benutzer-Loeschen:</b>".$sQuery."</p>";
-        }
+        debugIntoFile("Benutzer-Loeschen-Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo "<p><b>Benutzer-Loeschen:</b>".$sQuery."</p>";
+        #}
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
@@ -677,17 +749,18 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             $OPPID . "," .
             $_POST['OPPRIO']. ",".
             $OPUID_ASSIGNED . ", ".$_SESSION['OPUID'].", ".$_SESSION['OPUID'].")";
-        if ($debugSQL == 1) {
-            echo "<p><b>Insert OP-Entry:</b>".$sQuery."</p>";
-        }
+        debugIntoFile("Neuer-OP-Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo "<p><b>Insert OP-Entry:</b>".$sQuery."</p>";
+        #}
         #exit;
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
-        #debugMe("I am the debug Tester");
-        debugMe("<p>mailModus <b>".$mailModus."</b></p>");
-        debugMe("<p>debugMail <b>".$debugMail."</b></p>");
-        debugMe("<p>debugSQL <b>".$debugSQL."</b></p>");
+        #logIntoFile("I am the debug Tester");
+        logIntoFile("mailModus <".$mailModus.">");
+        logIntoFile("debugMail <".$debugMail.">");
+        logIntoFile("debugSQL  <".$debugSQL.">");
         if ($mailModus == 1 || $mailModus == 2) {
             # wir schicken den Betroffenen eine Email
             $email['FROMMAIL'] = getEmailOfId ($_SESSION['OPUID']);
@@ -697,19 +770,17 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
             $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
             $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$OPUID_ASSIGNED.") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
-            if ($debugSQL == 1) {
-                echo "<p><b>Emails-Select for Inserting new OP entry:</b>".$sQuery."</p>";
-            }
+            debugIntoFile("Email-Select: <".$sQuery.">");
+            #if ($debugSQL == 1) {
+            #    echo "<p><b>Emails-Select for Inserting new OP entry:</b>".$sQuery."</p>";
+            #}
             $result = getRessource($sQuery);
             echo getError();
             while ($val = getRow($result)) {
-                debugMe("<p>email <b>".$val['OPUEMAIL']."</b></p>");
+                logIntoFile("email <".$val['OPUEMAIL'].">");
                 $email['TOMAIL'] = $val['OPUEMAIL'];
-                if ($debugMail == 1) {
-                    debugMe("<p>Entry Debug</p>");
-                    debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
-                } else {
-                    debugMe("<p>Enailing</p>");
+                debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
+                if ($debugMail == 0) {
                     @mail($email['TOMAIL'], $email['SUBJECT'], $email['MSG'], $email['HEADERS']);
                 }
             }
@@ -717,6 +788,32 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         }
     } else if (isset($_POST['addcomment'])) {
         $OPCPRIVATE = "0";
+
+        if (isset ($_POST["OPCHANGESTATUS"]) && $_POST["OPCHANGESTATUS"] == "on") {
+            // we will change the status directly
+            if ($_SESSION['OPGID'] == 2) {
+                logIntoFile("Status FERTIG von Kunde gesetzt");
+                $NEWSTATUS=4;
+            } else {
+                logIntoFile("Status FERTIG von IBN oder SYS gesetzt");
+                $NEWSTATUS=3;
+            }
+            if ($usedb == "mysql") {
+                $sQuery = "UPDATE OPLIST set OPSID = ".$NEWSTATUS." WHERE OPID = ".$_POST["OPID"];
+                debugIntoFile("Update-OP-auf-Fertig-Select: <".$sQuery.">");
+                $result = getRessource($sQuery);
+                echo getError();
+                freeRessource($result);
+            } else if ($usedb == "oracle") {
+                $sQuery = "UPDATE OPLIST set OPSID = ".$NEWSTATUS." WHERE OPID = ".$_POST["OPID"];
+                debugIntoFile("Update-OP-auf-Fertig-Select: <".$sQuery.">");
+                $result = getRessource($sQuery);
+                echo getError();
+                freeRessource($result);
+            }
+        }
+
+
         if (isset ($_POST["OPCPRIVATE"]) && $_POST["OPCPRIVATE"] == "on") {
             $OPCPRIVATE = "1";
         }
@@ -729,18 +826,20 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         if (!empty($_FILES['datei']['name'])) {
             if ($usedb == "mysql") {
                 $sQuery = "INSERT INTO OPLIST_FILE (OPLFT) VALUES (1)";
-                if ($debugSQL == 1) {
-                    echo "<p><b>Naechste File-Id ermitteln-Select:</b>".$sQuery."</p>";
-                }
+                debugIntoFile("Naechste-File-Id-ermitteln-Select: <".$sQuery.">");
+                #if ($debugSQL == 1) {
+                #    echo "<p><b>Naechste File-Id ermitteln-Select:</b>".$sQuery."</p>";
+                #}
                 $result = getRessource($sQuery);
                 freeRessource($result);
 
                 $newFileName = mysql_insert_id();
             } else if ($usedb == "oracle") {
                 $sQuery = "SELECT OPLISTFILENAME_SEQ.NEXTVAL FROM DUAL";
-                if ($debugSQL == 1) {
-                    echo "<p><b>Naechster Attachment-Select:</b>".$sQuery."</p>";
-                }
+                debugIntoFile("Naechstes-Attachment-Select: <".$sQuery.">");
+                #if ($debugSQL == 1) {
+                #    echo "<p><b>Naechster Attachment-Select:</b>".$sQuery."</p>";
+                #}
                 $result = getRessource($sQuery);
                 echo getError();
                 while ($val = getRow($result)) {
@@ -765,9 +864,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         }
 
         $sQuery = "INSERT INTO OPLIST_COMMENT (OPCID, OPUID, OPCTEXT, OPID, OPCPRIVATE, OPCFILENAME) VALUES (".$nextId.", ".$_SESSION['OPUID'].", '".$_POST["OPCTEXT"]."', ".$_POST["OPID"].", ".$OPCPRIVATE.", ".$newFileName.")";
-        if ($debugSQL == 1) {
-            echo "<p><b>Insert-Kommentar:</b>".$sQuery."</p>";
-        }
+        debugIntoFile("Insert-Kommentar-Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo "<p><b>Insert-Kommentar:</b>".$sQuery."</p>";
+        #}
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
@@ -779,9 +879,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         }
 
         $sQuery = "UPDATE OPLIST SET OPDATEUPDATED = ".$dateNow.", OPUID_UPDATED = ".$_SESSION['OPUID']." WHERE OPID = ".$_POST["OPID"];
-        if ($debugSQL == 1) {
-            echo "<p><b>Update-OP-Entry:</b>".$sQuery."</p>";
-        }
+        debugIntoFile("Aktualisiere-OP-Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo "<p><b>Update-OP-Entry:</b>".$sQuery."</p>";
+        #}
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
@@ -789,18 +890,19 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
 
         if ($mailModus == 1) {
             $sendMail = 0;
-            debugMe("<p>Oeffentlicher Eintrag (0) <b>".$OPCPRIVATE."</b></p>");
+            logIntoFile("Oeffentlicher Eintrag (0) <".$OPCPRIVATE.">");
             if ($OPCPRIVATE == 0) {
-                debugMe("<p>OP erhaelt einen oeffentlichen Kommentar --> Email an Eigentümer</b></p>");
+                logIntoFile("OP erhaelt einen oeffentlichen Kommentar --> Email an Eigentümer");
                 # Email an OP-Ersteller
                 #echo "Email an Eigentuemer";
                 $sendMail = 1;
                 $tempFromEmail = $_SESSION['OPUID'];
                 $email['FROMMAIL'] = getEmailOfId ($_SESSION['OPUID']);
                 $sQuery = "SELECT OPUID_ASSIGNED, OPUID_CREATED, OPENTRY FROM OPLIST WHERE OPID = ".$_POST['OPID'];
-                if ($debugSQL == 1) {
-                    echo "<p><b>Select:</b>".$sQuery."</p>";
-                }
+                debugIntoFile("Select: <".$sQuery.">");
+                #if ($debugSQL == 1) {
+                #    echo "<p><b>Select:</b>".$sQuery."</p>";
+                #}
                 $result = getRessource($sQuery);
                 echo getError();
                 while ($rows = getRow($result )) {
@@ -818,16 +920,16 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
                 $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
                 $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
                 $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$tempToMail.",".$assigned.") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
-                if ($debugSQL == 1) {
-                    echo "<p><b>Select:</b>".$sQuery."</p>";
-                }
+                debugIntoFile("Select: <".$sQuery.">");
+                #if ($debugSQL == 1) {
+                #    echo "<p><b>Select:</b>".$sQuery."</p>";
+                #}
                 $result = getRessource($sQuery);
                 echo getError();
                 while ($val = getRow($result)) {
                     $email['TOMAIL'] = $val['OPUEMAIL'];
-                    if ($debugMail == 1) {
-                        debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
-                    } else {
+                    debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
+                    if ($debugMail == 0) {
                         @mail($email['TOMAIL'], $email['SUBJECT'], $email['MSG'], $email['HEADERS']);
                     }
                 }
@@ -838,9 +940,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
         if ($mailModus == 2) {
             # wir schicken immer eime Email
             $sQuery = "SELECT OPUID_ASSIGNED, OPENTRY, OPUID_CREATED FROM OPLIST WHERE OPDELETED = 0 AND OPID = ".$_POST["OPID"];
-            if ($debugSQL == 1) {
-                echo "<p><b>OP-Entry4Email-Select:</b>".$sQuery."</p>";
-            }
+            debugIntoFile("OP4Email-Select: <".$sQuery.">");
+            #if ($debugSQL == 1) {
+            #    echo "<p><b>OP-Entry4Email-Select:</b>".$sQuery."</p>";
+            #}
             $result = getRessource($sQuery);
             $AssignedUser = 0;
             $OPName = null;
@@ -862,16 +965,16 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
 
             $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$AssignedUser.") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
-            if ($debugSQL == 1) {
-                echo "<p><b>Email-Select:</b>".$sQuery."</p>";
-            }
+            debugIntoFile("Email-Select: <".$sQuery.">");
+            #if ($debugSQL == 1) {
+            #    echo "<p><b>Email-Select:</b>".$sQuery."</p>";
+            #}
             $result = getRessource($sQuery);
             echo getError();
             while ($val = getRow($result)) {
                 $email['TOMAIL'] = $val['OPUEMAIL'];
-                if ($debugMail == 1) {
-                    debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
-                } else {
+                debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
+                if ($debugMail == 0) {
                     @mail($email['TOMAIL'], $email['SUBJECT'], $email['MSG'], $email['HEADERS']);
                 }
             }
@@ -880,9 +983,8 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             #echo $Owner."|".$_SESSION['OPUID'];
             if ($Owner != $_SESSION['OPUID']) {
                 $email['TOMAIL'] = getEmailOfId ($Owner);
-                if ($debugMail == 1) {
-                    debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
-                } else {
+                debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
+                if ($debugMail == 0) {
                     @mail($email['TOMAIL'], $email['SUBJECT'], $email['MSG'], $email['HEADERS']);
                 }
             }
@@ -903,9 +1005,10 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
 
         $oldBugStatus = 0;
         $sQuery = "SELECT OPSID, OPUID_CREATED, OPUID_ASSIGNED FROM OPLIST WHERE OPID = ".$_POST['OPID'];
-        if ($debugSQL == 1) {
-            echo "<p><b>Select:</b>".$sQuery."</p>";
-        }
+        debugIntoFile("Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo "<p><b>Select:</b>".$sQuery."</p>";
+        #}
         $result = getRessource($sQuery);
         echo getError();
         while ($rows = getRow($result )) {
@@ -935,21 +1038,22 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             OPUID_UPDATED = ".$_SESSION['OPUID'].",
             OPUID_ASSIGNED = ".$_POST['OPUID_ASSIGNED']."
             WHERE OPID = ".$_POST['OPID'];
-        if ($debugSQL == 1) {
-            echo "<p><b>Update-OP-Entry:</b>".$sQuery."</p>";
-        }
+        debugIntoFile("Aktualisiere-OP-Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo "<p><b>Update-OP-Entry:</b>".$sQuery."</p>";
+        #}
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
 
         if ($mailModus == 1) {
             $sendMail = 0;
-            debugMe("<p>New Assigned to <b>".$_POST['OPUID_ASSIGNED']."</b></p>");
-            debugMe("<p>New OP-Status <b>".$_POST['OPSID']."</b></p>");
-            debugMe("<p>oldUIdAssigned <b>".$oldUIdAssigned."</b></p>");
-            debugMe("<p>oldOPStatus <b>".$oldBugStatus."</b></p>");
+            logIntoFile("New Assigned to <".$_POST['OPUID_ASSIGNED'].">");
+            logIntoFile("New OP-Status   <".$_POST['OPSID'].">");
+            logIntoFile("oldUIdAssigned  <".$oldUIdAssigned.">");
+            logIntoFile("oldOPStatus     <".$oldBugStatus.">");
             if ($oldUIdAssigned == 0 && $_POST['OPUID_ASSIGNED'] != 0) {
-                debugMe("<p>OP war nicht zugewiesen und ist nun zugewiesen --> Email an zugewiesenen IBN</b></p>");
+                logIntoFile("OP war nicht zugewiesen und ist nun zugewiesen --> Email an zugewiesenen IBN");
                 # Email an zugewiesenen IBN
                 #echo "Email an IBN";
                 $sendMail = 1;
@@ -957,7 +1061,7 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
                 $email['FROMMAIL'] = getEmailOfId ($oldUIdCreated);
                 $tempToMail = $_POST['OPUID_ASSIGNED'];
             } else if (($oldBugStatus == 1 || $oldBugStatus == 2) && $_POST['OPSID'] == 3) {
-                debugMe("<p>OP hatte Status offen oder in Bearbeitung und wechselt nun zu erledigt --> Email an OP-Eigentümer</b></p>");
+                logIntoFile("OP hatte Status offen oder in Bearbeitung und wechselt nun zu erledigt --> Email an OP-Eigentümer");
                 # Email an OP-Ersteller
                 #echo "Email an Eigentuemer";
                 $sendMail = 1;
@@ -965,8 +1069,8 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
                 $email['FROMMAIL'] = getEmailOfId ($_SESSION['OPUID']);
                 $tempToMail = $oldUIdCreated;
             } else if ((($oldBugStatus == 3 || $oldBugStatus == 4) && $_POST['OPSID'] != $oldBugStatus) || (($oldBugStatus == 1 || $oldBugStatus == 2 || $oldBugStatus == 3) && $_POST['OPSID'] == 4))  {
-                debugMe("<p>OP hatte Status erledigt oder abgeschlossen und der Status wurde auf offen oder in Bearbeitung gestellt --> Email an zugewiesenen IBN</b></p>");
-                debugMe("<p>oder: OP hatte Status offen, in Bearbeitung oder erledigt und wird auf Status abgeschlossen gedreht --> Email an IBN </b></p>");
+                logIntoFile("OP hatte Status erledigt oder abgeschlossen und der Status wurde auf offen oder in Bearbeitung gestellt --> Email an zugewiesenen IBN");
+                logIntoFile("oder: OP hatte Status offen, in Bearbeitung oder erledigt und wird auf Status abgeschlossen gedreht --> Email an IBN");
                 # Email an zugewiesenen IBN
                 #echo "Email an IBN2";
                 $sendMail = 1;
@@ -981,16 +1085,16 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
                 $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
                 $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
                 $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$tempToMail.") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
-                if ($debugSQL == 1) {
-                    echo "<p><b>Email-Select:</b>".$sQuery."</p>";
-                }
+                debugIntoFile("Email-Select: <".$sQuery.">");
+                #if ($debugSQL == 1) {
+                #    echo "<p><b>Email-Select:</b>".$sQuery."</p>";
+                #}
                 $result = getRessource($sQuery);
                 echo getError();
                 while ($val = getRow($result)) {
                     $email['TOMAIL'] = $val['OPUEMAIL'];
-                    if ($debugMail == 1) {
-                        debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
-                    } else {
+                    debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
+                    if ($debugMail == 0) {
                         @mail($email['TOMAIL'], $email['SUBJECT'], $email['MSG'], $email['HEADERS']);
                     }
                 }
@@ -1004,16 +1108,16 @@ if (empty($_SESSION['OPUID']) || empty($_SESSION['OPGID'])) {
             $email['HEADERS'] .= "From: <".$email['FROMMAIL'].">\n";
             $email['HEADERS'] .= "Reply-To: <".$email['FROMMAIL'].">\n";
             $sQuery = "SELECT DISTINCT OPUEMAIL FROM OPLIST_USERS WHERE (OPUID in (".$_POST['OPUID_ASSIGNED'].") OR (OPGID = ".$mailGroup.")) AND OPUACTIVE = 1 AND OPUEMAIL IS NOT NULL AND OPUID != ".$_SESSION['OPUID'];
-            if ($debugSQL == 1) {
-                echo "<p><b>Email-Select:</b>".$sQuery."</p>";
-            }
+            debugIntoFile("Email-Select: <".$sQuery.">");
+            #if ($debugSQL == 1) {
+            #    echo "<p><b>Email-Select:</b>".$sQuery."</p>";
+            #}
             $result = getRessource($sQuery);
             echo getError();
             while ($val = getRow($result)) {
                 $email['TOMAIL'] = $val['OPUEMAIL'];
-                if ($debugMail == 1) {
-                    debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
-                } else {
+                debugIntoDB ($email['TOMAIL']."|".$email['SUBJECT']."|".$email['MSG']."|".$email['HEADERS']);
+                if ($debugMail == 0) {
                     @mail($email['TOMAIL'], $email['SUBJECT'], $email['MSG'], $email['HEADERS']);
                 }
             }
@@ -1091,9 +1195,10 @@ WHERE OPA.OPAID = OP.OPAID
     AND OPUA.OPUID = OP.OPUID_ASSIGNED".$tempFilter.$groupFilter."
 ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED DESC";
     }
-    if ($debugSQL == 1) {
-        echo "<p><b>OP-Listen-Select:</b>".$sQuery."</p>";
-    }
+    debugIntoFile("OP-Listen-Select: <".$sQuery.">");
+    #if ($debugSQL == 1) {
+    #    echo "<p><b>OP-Listen-Select:</b>".$sQuery."</p>";
+    #}
     $result = getRessource($sQuery);
     echo getError();
     $bugArr = array();
@@ -1103,9 +1208,10 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
     freeRessource($result);
 
     $sQuery = "SELECT OPGID, OPGTEXT FROM OPLIST_GROUP WHERE (ACTIVE=1) ORDER BY OPGTEXT";
-    if ($debugSQL == 1) {
-        echo "<p><b>OP-Gruppen-Select:</b>".$sQuery."</p>";
-    }
+    debugIntoFile("OP-Gruppen-Select: <".$sQuery.">");
+    #if ($debugSQL == 1) {
+    #    echo "<p><b>OP-Gruppen-Select:</b>".$sQuery."</p>";
+    #}
     $result = getRessource($sQuery);
     echo getError();
     $grpArr = array();
@@ -1116,9 +1222,10 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
 
     if ($mode == "edit") {
         $sQuery = "SELECT * FROM OPLIST WHERE OPDELETED = 0 AND OPID = '".$_GET['OPID']."'";
-        if ($debugSQL == 1) {
-            echo $sQuery;
-        }
+        debugIntoFile("Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo $sQuery;
+        #}
         $result = getRessource($sQuery);
         echo getError();
         while ($rows = getRow($result )) {
@@ -1138,9 +1245,10 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
         freeRessource($result);
     } else if ($mode == "del") {
         $sQuery = "UPDATE OPLIST SET OPDELETED = 1 WHERE OPID = '".$_GET['OPID']."'";
-        if ($debugSQL == 1) {
-            echo $sQuery;
-        }
+        debugIntoFile("Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo $sQuery;
+        #}
         $result = getRessource($sQuery);
         echo getError();
         freeRessource($result);
@@ -1155,9 +1263,10 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
         $tmpHTML .= "Eintrag gel&ouml;scht.";
     } else if ($mode == "comment") {
         $sQuery = "SELECT * FROM OPLIST WHERE OPDELETED = 0 AND OPID = '".$_GET['OPID']."'";
-        if ($debugSQL == 1) {
-            echo $sQuery;
-        }
+        debugIntoFile("Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo $sQuery;
+        #}
         $result = getRessource($sQuery);
         echo getError();
         while ($rows = getRow($result )) {
@@ -1209,9 +1318,10 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
         }
 
         $sQuery = "SELECT OPC.OPCFILENAME, OPC.OPCID, OPC.OPCTEXT, ".$beforeToChar."OPC.OPCDATE".$afterToChar." OPCDATE, OPU.OPUUSERNAME, OPC.OPCPRIVATE FROM OPLIST_COMMENT OPC, OPLIST_USERS OPU WHERE OPC.OPID = ".$_GET['OPID']." AND OPU.OPUID = OPC.OPUID".$tempSQL." ORDER BY OPC.OPCID";
-        if ($debugSQL == 1) {
-            echo $sQuery;
-        }
+        debugIntoFile("Select: <".$sQuery.">");
+        #if ($debugSQL == 1) {
+        #    echo $sQuery;
+        #}
         $result = getRessource($sQuery);
         echo getError();
         while ($rows = getRow($result )) {
@@ -1242,12 +1352,13 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
             <td></td>
             <td valign=top>
             <textarea name="OPCTEXT" style="width:750px;" rows=10></textarea>
-            <input type="file" name="datei">';
+            <input type="file" name="datei"><br>';
         if ($_SESSION['OPGID'] != "2") {
             $tmpHTML .= '
-                <br>
-                <b>nur f&uuml;r INTERN:</b>&nbsp;<input name="OPCPRIVATE" type="checkbox" checked>';
+                <b>interner Kommentar:</b>&nbsp;<input name="OPCPRIVATE" type="checkbox" checked>';
         }
+        $tmpHTML .= '
+            <b>Status auf FERTIG stellen:</b>&nbsp;<input name="OPCHANGESTATUS" type="checkbox" unchecked>';
         $tmpHTML .= '
 
             </td>
@@ -1464,7 +1575,7 @@ ORDER BY OP.OPSID ASC, OP.OPPRIO DESC, OP.OPDATEUPDATED DESC, OP.OPDATEUPDATED D
                 $tmpHTML .=  "<a href='" .$_SERVER['PHP_SELF'] . "?mode=edit&OPID=".$v['OPID']."'><img src='img/edit.png' hspace=2 border=0></a>";
             }
             if ($_SESSION['OPGID'] == "1") {
-                $tmpHTML .=  "<a href=\"" .$_SERVER['PHP_SELF'] . "?mode=del&OPID=".$v['OPID']."\" onClick=\"return(confirmDialog('Wollen Sie diesen OP-Punkt wirklich loeschen?'));\"><img src='img/deletenew.png' hspace=2 border=0></a>";
+                $tmpHTML .=  "<a href=\"" .$_SERVER['PHP_SELF'] . "?mode=del&OPID=".$v['OPID']."\" onClick=\"return(confirmDialogIntoFile('Wollen Sie diesen OP-Punkt wirklich loeschen?'));\"><img src='img/deletenew.png' hspace=2 border=0></a>";
             }
 
             $tmpHTML .=  "</td><td valign='top' style='font-size:10px;'>".$v['OPID']."</td>
